/**
 | File: gammln.c
 |
 | A procedure that returns the logarithm of the Gamma function.
 |
 | From: Press, Teukolsky, Vetterling and Flannery -- Numerical
 |       Recipes in C (2nd Ed.) -- Cambridge University Press
 |       (1992) -- Pag. 214 .
 |
 | $Id: gammln.c,v 1.1 1999/05/18 13:37:46 loreti Exp $
 |
**/

#include <math.h>
#include "gammln.h"

double gammln(
  double xx
){
  double x, y, tmp, ser;
  int j;
  static double cof[6] = {
    76.18009172947146, -86.50532032941677, 24.01409824083091,
    -1.231739572450155, 0.1208650973866179e-2, -0.5395239384953e-5
  };
 
  y = x = xx;
  tmp = x + 5.5;
  tmp -= (x + 0.5) * log(tmp);
  ser = 1.000000000190015;
  for (j = 0;  j < 6;  j++) {
    y += 1.0;
    ser += cof[j] / y;
  }
  return -tmp + log(2.5066282746310005 * ser / x);
}
