#ifndef RANNUM_H_
#define RANNUM_H_

/**
 | Original package: randomnumber, last modified Fri Mar 18 07:28:57 1988
 | by Vincent Broman <broman@schroeder.nosc.mil> (public domain, and
 | posted on comp.lang.c)
 |
 | Modified by Maurizio Loreti (MLO), loreti@padova.infn.it;
 |
 | $Id: rannum.h,v 1.1 1999/05/18 13:37:46 loreti Exp $
 |
 | This package makes available Marsaglia's highly portable generator of
 | uniformly distributed pseudo-random numbers.  The sequence of 24 bit
 | pseudo-random numbers produced has a period of about 2**144, and has
 | passed stringent statistical tests for randomness and independence.
 |
 | Supplying two seeds to ranSetSeed is *REQUIRED* once at the program
 | startup, before requesting any random numbers, like:
 |
 |      ranSetSeet(101, 202); ... r = ranNum();
 |
 | The correspondence between pairs of seeds and generated sequences of
 | pseudo-random numbers is many-to-one.  This package should compile
 | and run identically on any machine/compiler which supports >=16 bit
 | integer arithmetic and >=24 bit floating point arithmetic.
 |
 | References:
 |      M. G. Harmon, T. P. Baker: "An Ada Implementation of Marsaglia's
 |      'Universal' Random Number Generator", Ada Letters, late 1987.
 |
 |      G. Marsaglia, "Toward a universal random number generator", to
 |      appear in the Journal of the American Statistical Association and
 |      Florida State University report FSU-SCRI-87-50.
 |
 |      F. James, Comp. Phys. Comm. 60 (1990), pag. 329; F. James coded
 |      a FORTRAN 77 implementation as the routine RANMAR of the CERN HEP
 |      mathematical library (MATHLIB).
 |
 | George Marsaglia is at the Supercomputer Computations Research Institute
 | at Florida State University.
**/

void   ranSetSeed(int seed_a, int seed_b);
double ranNum(void);

#endif
